==> sight_21.0.0.orig.tar.gz: sight-21.0.0/modules/viz/scene3d/adaptor/SRenderStats.hpp <==
/************************************************************************
 *
 * Copyright (C) 2018-2021 IRCAD France
 * Copyright (C) 2018-2021 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include "modules/viz/scene3d/config.hpp"

#include <viz/scene3d/IAdaptor.hpp>
#include <viz/scene3d/Text.hpp>

#include <OGRE/OgreColourValue.h>

#include <memory>

namespace sight::module::viz::scene3d::adaptor
{

class PostWindowRenderListener;

/**
 * @brief This adaptor displays rendering statistics in the window overlay.
 *
 * Displays the last FPS and the triangle count.
 *
 * @section XML XML Configuration
 * @code{.xml}
    <service uid="renderStatsAdaptor" type="sight::module::viz::scene3d::adaptor::SRenderStats">
        <config layer="default" color="#ff0000" fontSize="12"/>
    </service>
   @endcode
 *
 * @subsection Configuration Configuration:
 * - \b layer (mandatory, string): not really used but it is needed to be bound to a render service.
 * - \b color (optional, hexadecimal, default=#FFFFFF): stats' text color
 * - \b fontSize (optional, unsigned int, default=12): stats font size in points.
 */
class MODULE_VIZ_SCENE3D_CLASS_API SRenderStats final : public sight::viz::scene3d::IAdaptor
{
public:

    /// Generates default methods as New, dynamicCast, ...
    SIGHT_DECLARE_SERVICE(SRenderStats, ::sight::viz::scene3d::IAdaptor);

    /// Creates the adaptor.
    MODULE_VIZ_SCENE3D_API SRenderStats() noexcept;

    /// Destroys the adaptor.
    MODULE_VIZ_SCENE3D_API ~SRenderStats() noexcept override;

protected:

    /// Configures stats color and size.
    MODULE_VIZ_SCENE3D_API void configuring() override;

    /// Initializes the overlay text displaying the stats.
    MODULE_VIZ_SCENE3D_API void starting() override;

    /// Does nothing.
    MODULE_VIZ_SCENE3D_API void updating() override;

    /// Destroys the overlay text.
    MODULE_VIZ_SCENE3D_API void stopping() override;

private:

    friend class PostWindowRenderListener;

    /// Contains the listener to frame update events and updates the stats text.
    std::unique_ptr<PostWindowRenderListener> m_listener;

    /// Contains the displays stats in the overlay.
    sight::viz::scene3d::Text* m_statsText {nullptr};

    /// Defines the text's color.
    ::Ogre::ColourValue m_textColor;

    /// Defines the text's font height in points.
    size_t m_fontSize {12};

    /// Defines the TrueType font source file.
    std::string m_fontSource {"DejaVuSans.ttf"};
};

} // namespace sight::module::viz::scene3d::adaptor.

==> sight_21.1.1.orig.tar.gz: sight-21.1.1/modules/viz/scene3d/adaptor/SRenderStats.hpp <==
/************************************************************************
 *
 * Copyright (C) 2018-2022 IRCAD France
 * Copyright (C) 2018-2021 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include "modules/viz/scene3d/config.hpp"

#include <viz/scene3d/IAdaptor.hpp>
#include <viz/scene3d/Text.hpp>

#include <OGRE/OgreColourValue.h>

#include <memory>

namespace sight::module::viz::scene3d::adaptor
{

class PostWindowRenderListener;

/**
 * @brief This adaptor displays rendering statistics in the window overlay.
 *
 * Displays the last FPS and the triangle count.
 *
 * @section XML XML Configuration
 * @code{.xml}
    <service uid="renderStatsAdaptor" type="sight::module::viz::scene3d::adaptor::SRenderStats">
        <config layer="default" color="#ff0000" fontSize="12"/>
    </service>
   @endcode
 *
 * @subsection Configuration Configuration:
 * - \b layer (mandatory, string): not really used but it is needed to be bound to a render service.
 * - \b color (optional, hexadecimal, default=#FFFFFF): stats' text color
 * - \b fontSize (optional, unsigned int, default=12): stats font size in points.
 */
class MODULE_VIZ_SCENE3D_CLASS_API SRenderStats final : public sight::viz::scene3d::IAdaptor
{
public:

    /// Generates default methods as New, dynamicCast, ...
    SIGHT_DECLARE_SERVICE(SRenderStats, sight::viz::scene3d::IAdaptor);

    /// Creates the adaptor.
    MODULE_VIZ_SCENE3D_API SRenderStats() noexcept;

    /// Destroys the adaptor.
    MODULE_VIZ_SCENE3D_API ~SRenderStats() noexcept override;

protected:

    /// Configures stats color and size.
    MODULE_VIZ_SCENE3D_API void configuring() override;

    /// Initializes the overlay text displaying the stats.
    MODULE_VIZ_SCENE3D_API void starting() override;

    /// Does nothing.
    MODULE_VIZ_SCENE3D_API void updating() override;

    /// Destroys the overlay text.
    MODULE_VIZ_SCENE3D_API void stopping() override;

private:

    friend class PostWindowRenderListener;

    /// Contains the listener to frame update events and updates the stats text.
    std::unique_ptr<PostWindowRenderListener> m_listener;

    /// Contains the displays stats in the overlay.
    sight::viz::scene3d::Text* m_statsText {nullptr};

    /// Defines the text's color.
    Ogre::ColourValue m_textColor;

    /// Defines the text's font height in points.
    std::size_t m_fontSize {12};

    /// Defines the TrueType font source file.
    std::string m_fontSource {"DejaVuSans.ttf"};
};

} // namespace sight::module::viz::scene3d::adaptor.
